@@ -1,20 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 2.1
+ *  of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free
+ *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 
@@ -29,6 +30,17 @@
 #include "gmime-iconv.h"
 
 
+/**
+ * SECTION: gmime-filter-charset
+ * @title: GMimeFilterCharset
+ * @short_description: Charset-conversion filter
+ * @see_also:
+ *
+ * A #GMimeFilter which is used for converting text from one charset
+ * to another.
+ **/
+
+
 static void g_mime_filter_charset_class_init (GMimeFilterCharsetClass *klass);
 static void g_mime_filter_charset_init (GMimeFilterCharset *filter, GMimeFilterCharsetClass *klass);
 static void g_mime_filter_charset_finalize (GObject *object);
@@ -272,7 +284,8 @@ filter_reset (GMimeFilter *filter)
  *
  * Creates a new #GMimeFilterCharset filter.
  *
- * Returns a new charset filter.
+ * Returns: a new charset filter or %NULL if the charset conversion is
+ * not possible.
  **/
 GMimeFilter *
 g_mime_filter_charset_new (const char *from_charset, const char *to_charset)
@@ -284,7 +297,7 @@ g_mime_filter_charset_new (const char *from_charset, const char *to_charset)
 	if (cd == (iconv_t) -1)
 		return NULL;
 	
-	new = g_object_new (GMIME_TYPE_FILTER_CHARSET, NULL);
+	new = g_object_newv (GMIME_TYPE_FILTER_CHARSET, 0, NULL);
 	new->from_charset = g_strdup (from_charset);
 	new->to_charset = g_strdup (to_charset);
 	new->cd = cd;
