@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -232,7 +232,7 @@ g_mime_filter_crlf_new (gboolean encode, gboolean dots)
 {
 	GMimeFilterCRLF *new;
 	
-	new = g_object_new (GMIME_TYPE_FILTER_CRLF, NULL);
+	new = g_object_newv (GMIME_TYPE_FILTER_CRLF, 0, NULL);
 	new->encode = encode;
 	new->dots = dots;
 	
