@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -92,7 +92,7 @@ g_mime_header_new (const char *name, const char *value, gint64 offset)
 {
 	GMimeHeader *header;
 	
-	header = g_new (GMimeHeader, 1);
+	header = g_slice_new (GMimeHeader);
 	header->name = g_strdup (name);
 	header->value = g_strdup (value);
 	/*header->offset = offset;*/
@@ -114,7 +114,8 @@ g_mime_header_free (GMimeHeader *header)
 {
 	g_free (header->name);
 	g_free (header->value);
-	g_free (header);
+	
+	g_slice_free (GMimeHeader, header);
 }
 
 
@@ -133,7 +134,7 @@ g_mime_header_iter_new (void)
 {
 	GMimeHeaderIter *iter;
 	
-	iter = g_new (GMimeHeaderIter, 1);
+	iter = g_slice_new (GMimeHeaderIter);
 	iter->hdrlist = NULL;
 	iter->cursor = NULL;
 	iter->version = 0;
@@ -194,7 +195,7 @@ g_mime_header_iter_free (GMimeHeaderIter *iter)
 {
 	g_return_if_fail (iter != NULL);
 	
-	g_free (iter);
+	g_slice_free (GMimeHeaderIter, iter);
 }
 
 
@@ -526,7 +527,7 @@ g_mime_header_list_new (void)
 {
 	GMimeHeaderList *headers;
 	
-	headers = g_new (GMimeHeaderList, 1);
+	headers = g_slice_new (GMimeHeaderList);
 	headers->writers = g_hash_table_new_full (g_mime_strcase_hash,
 						  g_mime_strcase_equal,
 						  g_free, NULL);
@@ -564,7 +565,8 @@ g_mime_header_list_destroy (GMimeHeaderList *headers)
 	g_hash_table_destroy (headers->writers);
 	g_hash_table_destroy (headers->hash);
 	g_free (headers->raw);
-	g_free (headers);
+	
+	g_slice_free (GMimeHeaderList, headers);
 }
 
 
@@ -654,16 +656,19 @@ g_mime_header_list_get (const GMimeHeaderList *headers, const char *name)
  * @name: header name
  * @value: header value
  *
- * Set the value of the first header with the name specified. If
- * @value is %NULL and the header, @name, had not been previously set,
- * a space will be set aside for it (useful for setting the order of
- * headers before values can be obtained for them) otherwise the
- * header will be unset.
+ * Set the value of the specified header. If @value is %NULL and the
+ * header, @name, had not been previously set, a space will be set
+ * aside for it (useful for setting the order of headers before values
+ * can be obtained for them) otherwise the header will be unset.
+ *
+ * Note: If there are multiple headers with the specified field name,
+ * the first instance of the header will be replaced and further
+ * instances will be removed.
  **/
 void
 g_mime_header_list_set (GMimeHeaderList *headers, const char *name, const char *value)
 {
-	GMimeHeader *header;
+	GMimeHeader *header, *next;
 	
 	g_return_if_fail (headers != NULL);
 	g_return_if_fail (name != NULL);
@@ -671,6 +676,20 @@ g_mime_header_list_set (GMimeHeaderList *headers, const char *name, const char *
 	if ((header = g_hash_table_lookup (headers->hash, name))) {
 		g_free (header->value);
 		header->value = g_strdup (value);
+		
+		header = header->next;
+		while (header->next) {
+			next = header->next;
+			
+			if (!g_ascii_strcasecmp (header->name, name)) {
+				/* remove/free the header */
+				list_unlink ((ListNode *) header);
+				g_mime_header_free (header);
+				headers->version++;
+			}
+			
+			header = next;
+		}
 	} else {
 		header = g_mime_header_new (name, value, -1);
 		list_append (&headers->list, (ListNode *) header);
