@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -23,12 +23,16 @@
 #include <config.h>
 #endif
 
+#include <stdlib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <string.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <fcntl.h>
 #include <errno.h>
+#include <time.h>
 
 #include "gmime-multipart.h"
 #include "gmime-utils.h"
@@ -423,9 +427,9 @@ g_mime_multipart_get_postface (GMimeMultipart *multipart)
 static void
 multipart_clear (GMimeMultipart *multipart)
 {
-	int i;
+	guint i;
 	
-	for (i = 0; i < (int) multipart->children->len; i++)
+	for (i = 0; i < multipart->children->len; i++)
 		g_object_unref (multipart->children->pdata[i]);
 	
 	g_ptr_array_set_size (multipart->children, 0);
@@ -556,7 +560,7 @@ multipart_remove_at (GMimeMultipart *multipart, int index)
 {
 	GMimeObject *part;
 	
-	if (index >= multipart->children->len)
+	if ((guint) index >= multipart->children->len)
 		return NULL;
 	
 	part = multipart->children->pdata[index];
@@ -592,7 +596,7 @@ multipart_get_part (GMimeMultipart *multipart, int index)
 {
 	GMimeObject *part;
 	
-	if (index >= multipart->children->len)
+	if ((guint) index >= multipart->children->len)
 		return NULL;
 	
 	part = multipart->children->pdata[index];
@@ -623,9 +627,9 @@ g_mime_multipart_get_part (GMimeMultipart *multipart, int index)
 static gboolean
 multipart_contains (GMimeMultipart *multipart, GMimeObject *part)
 {
-	int i;
+	guint i;
 	
-	for (i = 0; i < (int) multipart->children->len; i++) {
+	for (i = 0; i < multipart->children->len; i++) {
 		if (part == (GMimeObject *) multipart->children->pdata[i])
 			return TRUE;
 	}
@@ -657,9 +661,9 @@ g_mime_multipart_contains (GMimeMultipart *multipart, GMimeObject *part)
 static int
 multipart_index_of (GMimeMultipart *multipart, GMimeObject *part)
 {
-	int i;
+	guint i;
 	
-	for (i = 0; i < (int) multipart->children->len; i++) {
+	for (i = 0; i < multipart->children->len; i++) {
 		if (part == (GMimeObject *) multipart->children->pdata[i])
 			return i;
 	}
@@ -714,6 +718,7 @@ g_mime_multipart_get_count (GMimeMultipart *multipart)
 static void
 read_random_pool (unsigned char *buffer, size_t bytes)
 {
+#ifdef HAVE_UNISTD_H
 	size_t nread = 0;
 	ssize_t n;
 	int fd;
@@ -735,6 +740,14 @@ read_random_pool (unsigned char *buffer, size_t bytes)
 	} while (nread < bytes);
 	
 	close (fd);
+#else
+	size_t i;
+	
+	srand ((unsigned int) time (NULL));
+	
+	for (i = 0; i < bytes; i++)
+		buffer[i] = (unsigned char) (rand () % 256);
+#endif
 }
 
 static void
