@@ -39,7 +39,6 @@
 
 /*#define TEST_RAW_HEADER*/
 #define TEST_PRESERVE_HEADERS
-#define TEST_GET_BODY
 #define PRINT_MIME_STRUCT
 /*#define TEST_WRITE_TO_STREAM*/
 
@@ -56,7 +55,11 @@ static void
 print_mime_struct (GMimeObject *part, int depth)
 {
 	const GMimeContentType *type;
+	GMimeMultipart *multipart;
+	GMimeMessagePart *mpart;
+	GMimeObject *subpart;
 	gboolean has_md5;
+	int i, n;
 	
 	print_depth (depth);
 	type = g_mime_object_get_content_type (part);
@@ -65,15 +68,15 @@ print_mime_struct (GMimeObject *part, int depth)
 		 has_md5 ? "; md5sum=" : "\n");
 	
 	if (GMIME_IS_MULTIPART (part)) {
-		GList *subpart;
+		multipart = (GMimeMultipart *) part;
 		
-		subpart = GMIME_MULTIPART (part)->subparts;
-		while (subpart) {
-			print_mime_struct (subpart->data, depth + 1);
-			subpart = subpart->next;
+		n = g_mime_multipart_get_count (multipart);
+		for (i = 0; i < n; i++) {
+			subpart = g_mime_multipart_get_part (multipart, i);
+			print_mime_struct (subpart, depth + 1);
 		}
 	} else if (GMIME_IS_MESSAGE_PART (part)) {
-		GMimeMessagePart *mpart = (GMimeMessagePart *) part;
+		mpart = (GMimeMessagePart *) part;
 		
 		if (mpart->message)
 			print_mime_struct (mpart->message->mime_part, depth + 1);
@@ -91,7 +94,6 @@ test_parser (GMimeStream *stream)
 {
 	GMimeParser *parser;
 	GMimeMessage *message;
-	gboolean is_html;
 	char *text;
 	
 	fprintf (stdout, "\nTesting MIME parser...\n\n");
@@ -127,12 +129,12 @@ test_parser (GMimeStream *stream)
 	{
 		GMimeStream *stream;
 		
-		g_mime_header_set_raw (GMIME_OBJECT (message)->headers, NULL);
+		g_mime_header_list_set_raw (GMIME_OBJECT (message)->headers, NULL);
 		
 		fprintf (stdout, "\nTesting preservation of headers...\n\n");
 		stream = g_mime_stream_file_new (stdout);
 		/*g_mime_header_set_raw (GMIME_OBJECT (message)->headers, NULL);*/
-		g_mime_header_write_to_stream (GMIME_OBJECT (message)->headers, stream);
+		g_mime_header_list_write_to_stream (GMIME_OBJECT (message)->headers, stream);
 		g_mime_stream_flush (stream);
 		GMIME_STREAM_FILE (stream)->fp = NULL;
 		g_object_unref (stream);
@@ -140,20 +142,6 @@ test_parser (GMimeStream *stream)
 	}
 #endif
 	
-#ifdef TEST_GET_BODY
-	{
-		/* test of get_body */
-		char *body;
-		
-		body = g_mime_message_get_body (message, FALSE, &is_html);
-		fprintf (stdout, "Testing get_body (looking for html...%s)\n\n-->%s<--\n\n",
-			 body && is_html ? "found" : "not found",
-			 body ? body : "No message body found");
-		
-		g_free (body);
-	}
-#endif
-	
 #ifdef TEST_WRITE_TO_STREAM
 	stream = g_mime_stream_fs_new (2);
 	g_mime_object_write_to_stream (GMIME_OBJECT (message), stream);
